==> aliyun-secret-manager-client-0.0.2.tar.gz: aliyun-secret-manager-client-0.0.2/src/alibaba_cloud_secretsmanager_client/utils/env_const.py <==
# coding=utf-8
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License
# 环境变量 region_id key
ENV_CACHE_CLIENT_REGION_ID_KEY = "cache_client_region_id"
# 环境变量 credentials_type key
ENV_CREDENTIALS_TYPE_KEY = "credentials_type"
# 环境变量 credentials_access_key_id key
ENV_CREDENTIALS_ACCESS_KEY_ID_KEY = "credentials_access_key_id"
# 环境变量 credentials_access_secret key
ENV_CREDENTIALS_ACCESS_SECRET_KEY = "credentials_access_secret"
# 环境变量 credentials_access_token_id key
ENV_CREDENTIALS_ACCESS_TOKEN_ID_KEY = "credentials_access_token_id"
# 环境变量 credentials_access_token key
ENV_CREDENTIALS_ACCESS_TOKEN_KEY = "credentials_access_token"
# 环境变量 credentials_role_session_name key
ENV_CREDENTIALS_ROLE_SESSION_NAME_KEY = "credentials_role_session_name"
# 环境变量 credentials_role_arn key
ENV_CREDENTIALS_ROLE_ARN_KEY = "credentials_role_arn"
# 环境变量 credentials_role_name key
ENV_CREDENTIALS_ROLE_NAME_KEY = "credentials_role_name"
# 环境变量 region中 regionId key
ENV_REGION_REGION_ID_NAME_KEY = "regionId"
# 环境变量 region中 endpoint key
ENV_REGION_ENDPOINT_NAME_KEY = "endpoint"
# 环境变量 region中 vpc key
ENV_REGION_VPC_NAME_KEY = "vpc"

==> aliyun-secret-manager-client-0.0.4.tar.gz: aliyun-secret-manager-client-0.0.4/src/alibaba_cloud_secretsmanager_client/utils/env_const.py <==
# coding=utf-8
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License
# 环境变量 region_id key
ENV_CACHE_CLIENT_REGION_ID_KEY = "cache_client_region_id"
# 环境变量 credentials_type key
ENV_CREDENTIALS_TYPE_KEY = "credentials_type"
# 环境变量 credentials_access_key_id key
ENV_CREDENTIALS_ACCESS_KEY_ID_KEY = "credentials_access_key_id"
# 环境变量 credentials_access_secret key
ENV_CREDENTIALS_ACCESS_SECRET_KEY = "credentials_access_secret"
# 环境变量 credentials_access_token_id key
ENV_CREDENTIALS_ACCESS_TOKEN_ID_KEY = "credentials_access_token_id"
# 环境变量 credentials_access_token key
ENV_CREDENTIALS_ACCESS_TOKEN_KEY = "credentials_access_token"
# 环境变量 credentials_role_session_name key
ENV_CREDENTIALS_ROLE_SESSION_NAME_KEY = "credentials_role_session_name"
# 环境变量 credentials_role_arn key
ENV_CREDENTIALS_ROLE_ARN_KEY = "credentials_role_arn"
# 环境变量 credentials_role_name key
ENV_CREDENTIALS_ROLE_NAME_KEY = "credentials_role_name"
# 环境变量 region中 regionId key
ENV_REGION_REGION_ID_NAME_KEY = "regionId"
# 环境变量 region中 endpoint key
ENV_REGION_ENDPOINT_NAME_KEY = "endpoint"
# 环境变量 region中 vpc key
ENV_REGION_VPC_NAME_KEY = "vpc"
# 环境变量client_key_password key
ENV_CLIENT_KEY_PASSWORD_NAME_KEY = "client_key_password"
# 环境变量credentials_client_key_private_key_path key
EnvClientKeyPrivateKeyPathNameKey = "client_key_private_key_path"
# 环境变量 client_key_password_from_env_variable key
ENV_CLIENT_KEY_PASSWORD_FROM_ENV_VARIABLE_NAME = "client_key_password_from_env_variable"
